@@ -22,12 +22,12 @@ from __future__ import absolute_import
 import sys
 from . import context
 
-VERSION = (3, 6, 1, 0)
+VERSION = (3, 6, 2, 0)
 __version__ = '.'.join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
-__maintainer__ = 'Ask Solem'
-__contact__ = "ask@celeryproject.org"
+__maintainer__ = 'Asif Saif Uddin'
+__contact__ = "auvipy@gmail.com"
 __homepage__ = "https://github.com/celery/billiard"
 __docformat__ = "restructuredtext"
 
